function varargout = LiscenceInfo(varargin)
% LISCENCEINFO M-file for LiscenceInfo.fig
%      LISCENCEINFO, by itself, creates a new LISCENCEINFO or raises the existing
%      singleton*.
%
%      H = LISCENCEINFO returns the handle to a new LISCENCEINFO or the handle to
%      the existing singleton*.
%
%      LISCENCEINFO('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in LISCENCEINFO.M with the given input arguments.
%
%      LISCENCEINFO('Property','Value',...) creates a new LISCENCEINFO or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before LiscenceInfo_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to LiscenceInfo_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help LiscenceInfo

% Last Modified by GUIDE v2.5 21-May-2006 19:50:24

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @LiscenceInfo_OpeningFcn, ...
                   'gui_OutputFcn',  @LiscenceInfo_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before LiscenceInfo is made visible.
function LiscenceInfo_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to LiscenceInfo (see VARARGIN)

% Choose default command line output for LiscenceInfo
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes LiscenceInfo wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = LiscenceInfo_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on selection change in LiscenceBox.
function LiscenceBox_Callback(hObject, eventdata, handles)
% hObject    handle to LiscenceBox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns LiscenceBox contents as cell array
%        contents{get(hObject,'Value')} returns selected item from LiscenceBox


% --- Executes during object creation, after setting all properties.
function LiscenceBox_CreateFcn(hObject, eventdata, handles)
% hObject    handle to LiscenceBox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: listbox controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in CloseBtn.
function CloseBtn_Callback(hObject, eventdata, handles)
% hObject    handle to CloseBtn (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
delete(gcf)


